.. _analyse_hic:

===========================
Analyse Hi-C matrices (API)
===========================

The ``fanc`` tool should be accessible from the command line after you installed FAN-C
(see :ref:`fanc_installation`).
It provides convenient commands for the generation, modification, and analysis of Hi-C data.

.. note::

    The following tutorials assume you have downloaded all the example data files from
    `out GitHub page <https://github.com/vaquerizaslab/fanc/>`_ and ran the sample analysis outlined
    in :ref:`example-fanc-auto`.

.. toctree::
   :maxdepth: 2

    Expected values and O/E matrices <fanc-analyse-hic/oe>
    AB compartments <fanc-analyse-hic/ab_compartments>
    PCA <fanc-analyse-hic/pca>
    TADs and TAD boundaries <fanc-analyse-hic/domains>
    Matrix and score comparisons <fanc-analyse-hic/comparisons>
    Aggregate Hi-C matrices <fanc-analyse-hic/aggregate_hic>
    Loop calling <fanc-analyse-hic/loops>
